@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_020.php
 // Begin       : 2008-03-04
-// Last Update : 2010-05-20
+// Last Update : 2013-05-14
 //
 // Description : Example 020 for TCPDF class
 //               Two columns composed by MultiCell of different
@@ -12,10 +12,7 @@
 //
 // (c) Copyright:
 //               Nicola Asuni
-//               Tecnick.com s.r.l.
-//               Via Della Pace, 11
-//               09044 Quartucciu (CA)
-//               ITALY
+//               Tecnick.com LTD
 //               www.tecnick.com
 //               info@tecnick.com
 //============================================================+
@@ -25,38 +22,35 @@
 * @package com.tecnick.tcpdf
 * @abstract TCPDF - Example: Two columns composed by MultiCell of different heights
 * @author Nicola Asuni
-* @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
-* @link http://tcpdf.org
-* @license http://www.gnu.org/copyleft/lesser.html LGPL
 * @since 2008-03-04
 */
 
-require_once('../config/lang/eng.php');
-require_once('../tcpdf.php');
+// Include the main TCPDF library (search for installation path).
+require_once('tcpdf_include.php');
 
 // extend TCPF with custom functions
 class MYPDF extends TCPDF {
-	
+
 	public function MultiRow($left, $right) {
 		// MultiCell($w, $h, $txt, $border=0, $align='J', $fill=0, $ln=1, $x='', $y='', $reseth=true, $stretch=0)
-	
+
 		$page_start = $this->getPage();
 		$y_start = $this->GetY();
-	
+
 		// write the left cell
 		$this->MultiCell(40, 0, $left, 1, 'R', 1, 2, '', '', true, 0);
-	
+
 		$page_end_1 = $this->getPage();
 		$y_end_1 = $this->GetY();
-	
+
 		$this->setPage($page_start);
-	
+
 		// write the right cell
 		$this->MultiCell(0, 0, $right, 1, 'J', 0, 1, $this->GetX() ,$y_start, true, 0);
-	
+
 		$page_end_2 = $this->getPage();
 		$y_end_2 = $this->GetY();
-	
+
 		// set the new row position by case
 		if (max($page_end_1,$page_end_2) == $page_start) {
 			$ynew = max($y_end_1, $y_end_2);
@@ -67,7 +61,7 @@ class MYPDF extends TCPDF {
 		} else {
 			$ynew = $y_end_2;
 		}
-	
+
 		$this->setPage(max($page_end_1,$page_end_2));
 		$this->SetXY($this->GetX(),$ynew);
 	}
@@ -94,19 +88,22 @@ $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
 // set default monospaced font
 $pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
 
-//set margins
+// set margins
 $pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
 $pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
 $pdf->SetFooterMargin(PDF_MARGIN_FOOTER);
 
-//set auto page breaks
+// set auto page breaks
 $pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
 
-//set image scale factor
+// set image scale factor
 $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
 
-//set some language-dependent strings
-$pdf->setLanguageArray($l);
+// set some language-dependent strings (optional)
+if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
+	require_once(dirname(__FILE__).'/lang/eng.php');
+	$pdf->setLanguageArray($l);
+}
 
 // ---------------------------------------------------------
 
@@ -132,7 +129,7 @@ $text = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. In sed imperdi
 Fusce et felis vitae diam lobortis sollicitudin. Aenean tincidunt accumsan nisi, id vehicula quam laoreet elementum. Phasellus egestas interdum erat, et viverra ipsum ultricies ac. Praesent sagittis augue at augue volutpat eleifend. Cras nec orci neque. Mauris bibendum posuere blandit. Donec feugiat mollis dui sit amet pellentesque. Sed a enim justo. Donec tincidunt, nisl eget elementum aliquam, odio ipsum ultrices quam, eu porttitor ligula urna at lorem. Donec varius, eros et convallis laoreet, ligula tellus consequat felis, ut ornare metus tellus sodales velit. Duis sed diam ante. Ut rutrum malesuada massa, vitae consectetur ipsum rhoncus sed. Suspendisse potenti. Pellentesque a congue massa.';
 
 // print some rows just as example
-for ($i = 0; $i < 7; ++$i) {
+for ($i = 0; $i < 10; ++$i) {
 	$pdf->MultiRow('Row '.($i+1), $text."\n");
 }
 
@@ -145,6 +142,5 @@ $pdf->lastPage();
 $pdf->Output('example_020.pdf', 'I');
 
 //============================================================+
-// END OF FILE                                                
+// END OF FILE
 //============================================================+
-?>
